% Plot some useful trend plots summarizing the results of the simulations
% in /ligo/svncommon/SusSVN/sus/trunk/QUAD/Common/MatlabTools/QuadModel_Production/TMD_BounceAndRollModes_fullquad.m
% 
% Brett Shapiro
% 2 June 2015

% Data collected from simulations
muvec = [1e-5 2e-5 5e-5 10e-5 15e-5 20e-5 25e-5];        % mass ratio
df_SD = [0.00445 0.00630 0.01 0.01394 0.0172 0.0197 0.022]; % damping factor where K_structuraldamping = k*(1+i*df)
PUMmass = 39.6760; % kg
roll_leverarm = 0.1775; % m
PUMrollmass = PUMinertia/(roll_leverarm^2); % kg
bouncemodefreq = 9.6866; % Hz
rollmodefreq = 13.8069; % Hz
c_vert = 2.3*muvec*(PUMmass/2)*(2*pi*bouncemodefreq).*sqrt(3*muvec ./ (8*(1+muvec).^3));
c_roll = 2.3*(PUMrollmass/2)*(2*pi*rollmodefreq)*muvec.*sqrt(3*muvec ./ (8*(1+muvec).^3));
% Q0 = [461.5 330 213.5 154.5 128.5 113 102.5];            % average of bounce and roll Q with 0% tuning error on damper frequency
% Q0p1 = [1062.5 623.5 324.5 202.5 155 128 110];           % average of bounce and roll Q with 0.1% tuning error on damper frequency
% Q1 = [17974 6842 2062 902.5 576.5 426.5 340.5];          % average of bounce and roll Q with 1% tuning error on damper frequency
Q0 = [458 325.5 209 150 124 108.5 97.5];            % average of bounce and roll Q with 0% tuning error on damper frequency
Q0p1 = [1066.5 627.5 328 206.5 158.5 131 114];           % average of bounce and roll Q with 0.1% tuning error on damper frequency
Q1 = [18320 6976.5 2104.5 922 590.5 437.5 349.5];          % average of bounce and roll Q with 1% tuning error on damper frequency
Q0approx = 1.5./sqrt(muvec);                             % fit to the average of bounce and roll Q with 0% tuning error on damper frequency
ThermalNoise_TwentyHz_SD = ...
 [4.2683 4.4951 5.4118 7.177 8.96 10.693 12.368]*1e-21;  % thermal noise of damped system at 20 Hz
ThermalNoise_TwentyHz_VD = ...
 [5.6865 5.9084 6.8313 8.6856 10.616 12.522 14.382]*1e-21;  % thermal noise of damped system at 20 Hz

% where df is reduced by 0.5
df0p5 = df*0.5;
Q0_df0p5 = [904.5 641.5 408 291 239 208 186];
Q0p1_df0p5 = [1581 934 503.5 328 257.5 218.5 192];
Q1_df0p5 = [34644 12877.5 3672 1521.5 942 682 536.5];
ThermalNoise_TwentyHz_df0p5 = ...
[4.2041 4.3207 4.8176 5.8585 6.9793 8.1085 9.2233]*1e-21;


% % Damping factor
% figure,maxfig
% loglog(muvec,df,'-*','LineWidth',5,'MarkerSize',20),grid on,
% set(gca,'FontSize',35,'XLim',[muvec(1)*0.99999 muvec(end)])
% title('Ideal damping factor vs mass ratio')
% ylabel('Damping factor d')
% xlabel('Mass ratio \mu')
% legend('d= 2.3*sqrt[3\mu/(8*(1+\mu)^3)]')
% id_handle = IDfig('Brett Shapiro'); set(id_handle,'FontSize',12)

% Structural damping factor with 20 Hz thermal noise
figure,maxfig
    textsize = 35; linesize = 5;
    [AX,H1,H2] = plotyy(muvec,df_SD,muvec,ThermalNoise_TwentyHz_SD,'loglog');
    hold on
%     H3 = line(L,PijFit,'Parent', AX(1));
%     H4 = line(L,IijFit,'Parent', AX(2));
    grid on
    title('Ideal structural damping factor and 20 Hz thermal noise vs mass ratio ','FontSize',textsize)
    set(get(AX(1),'Ylabel'),'String','Damping factor d (unitless)','FontSize',textsize)
    set(get(AX(2),'Ylabel'),'String','20 Hz Thermal Noise (m/\surdHz)','FontSize',textsize)
    set(AX(1),'YTick',[0.001 0.01 0.1],'YTickLabel',{'1e-3','1e-2','1e-1'},'YLim',[0.001*0.99999 0.1],'XLim',[muvec(1)*0.99999 muvec(end)])
    set(AX(2),'YTick',[1e-21 1e-20 1e-19],'YTickLabel',{'1e-21','1e-20','1e-19'},'YLim',[1e-21*0.99999 1e-19],'XLim',[muvec(1)*0.99999 muvec(end)])
    set(H1,'LineWidth',linesize)
    set(H2,'LineWidth',linesize)
%     set(H3,'LineWidth',linesize)
%     set(H4,'LineWidth',linesize)
    set(H1,'Marker','*','MarkerSize',20)
    set(H2,'Marker','*','MarkerSize',20) % set(H2,'LineStyle','--')
    set(AX(1),'FontSize',textsize)%,'YLim',[-1,6],'YTick',linspace(-1,6,8))
    set(AX(2),'FontSize',textsize)%,'YLim',[-5,30],'YTick',linspace(-5,30,8))
    xlabel('Mass ratio \mu')
%     set(gcf,'Position',[150 150 1500 700]);
    legend('d= 2.3*sqrt[3\mu/(8*(1+\mu)^3)]','20 Hz thermal noise',2);
  
% Viscous damping coefficient with 20 Hz thermal noise
figure,maxfig
    textsize = 35; linesize = 5;
    [AX,H1,H2] = plotyy(muvec,c_vert,muvec,ThermalNoise_TwentyHz_VD,'loglog');
    hold on
%     H3 = line(L,PijFit,'Parent', AX(1));
%     H4 = line(L,IijFit,'Parent', AX(2));
    grid on
    title('Ideal viscous damping coefficient and 20 Hz thermal noise vs mass ratio ','FontSize',textsize)
    set(get(AX(1),'Ylabel'),'String','Damping factor c (N / m/s)','FontSize',textsize)
    set(get(AX(2),'Ylabel'),'String','20 Hz Thermal Noise (m/\surdHz)','FontSize',textsize)
    set(AX(1),'YTick',[0.00001 0.0001 0.001 0.01],'YTickLabel',{'1e-5','1e-4','1e-3','1e-2'},'YLim',[0.00001*0.99999 0.01],'XLim',[muvec(1)*0.99999 muvec(end)])
    set(AX(2),'YTick',[1e-21 1e-20 1e-19 1e-18],'YTickLabel',{'1e-21','1e-20','1e-19','1e-18'},'YLim',[1e-21*0.99999 1e-18],'XLim',[muvec(1)*0.99999 muvec(end)])
    set(H1,'LineWidth',linesize)
    set(H2,'LineWidth',linesize)
%     set(H3,'LineWidth',linesize)
%     set(H4,'LineWidth',linesize)
    set(H1,'Marker','*','MarkerSize',20)
    set(H2,'Marker','*','MarkerSize',20) % set(H2,'LineStyle','--')
    set(AX(1),'FontSize',textsize)%,'YLim',[-1,6],'YTick',linspace(-1,6,8))
    set(AX(2),'FontSize',textsize)%,'YLim',[-5,30],'YTick',linspace(-5,30,8))
    xlabel('Mass ratio \mu')
%     set(gcf,'Position',[150 150 1500 700]);
    hold on
    loglog(muvec,c_roll,'--*b','LineWidth',linesize,'MarkerSize',20)
    legend('c_v_e_r_t = 2777\musqrt[3\mu/(8(1+\mu)^3)]','c_r_o_l_l = 1750\musqrt[3\mu/(8(1+\mu)^3)]','20 Hz thermal noise',2);


% Qs
figure,maxfig
    loglog(muvec,Q0,'-*',muvec,Q0approx,'--k',muvec,Q0p1,'-*',muvec,Q1,'-*','LineWidth',5,'MarkerSize',20),grid on
    set(gca,'FontSize',35,'XLim',[muvec(1)*0.99999 muvec(end)])
    title('Damped bounce and roll Qs vs mass ratio')
    ylabel('Q')
    xlabel('Mass ratio \mu')
    legend('Perfect tuning','Perfect tuning fit = 1.5/\surd\mu','0.1% frequency error','1% frequency error')
    id_handle = IDfig('Brett Shapiro'); set(id_handle,'FontSize',12)